' Advantech Susi Watchdog Sample in VB.NET
'
' [Notice] Calling Susi APIs in VB.NET
' 1. Be sure to declare import functions as a Module
' 2. Data equivalence must be considered, 
'    esp. function with parameters in DWORD should be replaced with UInt32 (must not use "Long" or it will always return False)

Imports System.Runtime.InteropServices 'For dll import

Module PubFunc

    ' Please do use data type UInt32 for DWORD (must not use "Long" or the funtion call will always return with False)
    <DllImport("Susi.dll")> _
    Public Function SusiDllInit() As Boolean
    End Function
    <DllImport("Susi.dll")> _
    Public Function SusiDllUnInit() As Boolean
    End Function
    <DllImport("Susi.dll")> _
    Public Function SusiWDAvailable() As Boolean
    End Function
    <DllImport("Susi.dll")> _
    Public Function SusiWDDisable() As Boolean
    End Function
    <DllImport("Susi.dll")> _
    Public Function SusiWDGetRange(ByRef minimum As UInt32, ByRef maximum As UInt32, ByRef stepping As UInt32) As Boolean
    End Function
    <DllImport("Susi.dll")> _
    Public Function SusiWDSetConfig(ByVal delay As UInt32, ByVal timeout As UInt32) As Boolean
    End Function
    <DllImport("Susi.dll")> _
    Public Function SusiWDTrigger() As Boolean
    End Function
    <DllImport("Susi.dll")> _
    Public Function SusiDllGetLastError() As Integer
    End Function

End Module

Public Class Form1

    ' Global Variables
    Dim OrgTimeout As UInt32
    Dim TimeLeft As UInt32

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Dim minTime As UInt32
        Dim maxTime As UInt32
        Dim stepping As UInt32

        If (SusiDllInit() <> True) Then
            MessageBox.Show("SusiDllInit failed! " + "ErrorCode = " + SusiDllGetLastError().ToString())
        Else
            If (SusiWDGetRange(minTime, maxTime, stepping) <> True) Then
                MessageBox.Show("SusiWDGetRange failed! " + "ErrorCode = " + SusiDllGetLastError().ToString())
            Else
                textBoxWDTMin.Text = minTime
                textBoxWDTMax.Text = maxTime
                textBoxWDTStep.Text = stepping
            End If
        End If

    End Sub
    Private Sub buttonWDTRefresh_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles buttonWDTRefresh.Click

        If (SusiWDTrigger() <> True) Then
            MessageBox.Show("SusiWDTrigger failed! " + "ErrorCode = " + SusiDllGetLastError().ToString()) ' or you can still use the old style -> MsgBox("Refresh Watchdog failed.", , "ERROR")
        Else
            'Reset the timer when the watchdog is refreshed
            TimeLeft = OrgTimeout
            textBoxWDTLeft.Text = TimeLeft.ToString()
        End If

    End Sub
    Private Sub buttonWDTStop_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles buttonWDTStop.Click

        If (SusiWDDisable() <> True) Then
            MessageBox.Show("SusiWDDisable failed! " + "ErrorCode = " + SusiDllGetLastError().ToString())
        Else
            TimerWDT.Enabled = False
        End If

    End Sub

    Private Sub ButtonWDTStart_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ButtonWDTStart.Click

        Dim delay As UInt32 = Convert.ToInt32(textBoxWDTDelay.Text)
        Dim timeout As UInt32 = Convert.ToInt32(textBoxWDTTimeOut.Text)
        Dim timerCountDown As UInt32 = delay + timeout

        If (SusiWDSetConfig(delay, timeout) <> True) Then
            MessageBox.Show("SusiWDSetConfig failed! " + "ErrorCode = " + SusiDllGetLastError().ToString())
        Else
            OrgTimeout = timeout
            TimeLeft = timerCountDown
            textBoxWDTLeft.Text = timerCountDown.ToString()
            TimerWDT.Enabled = True
        End If

    End Sub

    Private Sub TimerWDT_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles TimerWDT.Tick

        If (TimeLeft >= TimerWDT.Interval) Then
            TimeLeft -= TimerWDT.Interval
        Else
            TimeLeft = 0
        End If

        textBoxWDTLeft.Text = TimeLeft.ToString()

    End Sub

    Private Sub Form1_Closed(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Closed
        SusiDllUnInit()
    End Sub
End Class



